@@ -157,7 +157,7 @@ async def cmd_give(msg: Message, *args):
         raise InvalidArgumentsError(reason=translate('missing_required_arguments'), cmd=cmd_give)
 
     caller = get_balance_from_msg(msg)
-    target = get_balance(msg.channel_name, msg.mentions[0])
+    target = get_balance(msg.channel_name, args[0], create_if_missing=True)
 
     try:
         give = int(args[1])
@@ -302,11 +302,12 @@ async def cmd_arena(msg: Message, *args):
         except KeyError:
             pass
 
-    arena = running_arenas.get(msg.channel_name)
+    Balance.ensure_exists(msg.channel_name, msg.author)
     curname = get_currency_name(msg.channel_name).name
 
     # arena is already running for this channel
-    if arena:
+    arena = running_arenas.get(msg.channel_name)
+    if arena is not None:
         if msg.author in arena.users:
             return await msg.reply(
                 whisper=True,
@@ -341,7 +342,8 @@ async def cmd_arena(msg: Message, *args):
         if not _can_pay_entry_fee(entry_fee):
             await msg.reply(
                 whisper=True,
-                msg=translate('arena_cannot_enter_not_enough_balance', mention=msg.mention, entry_fee=arena.entry_fee, currency=curname))
+                msg=translate('arena_cannot_enter_not_enough_balance', mention=msg.mention, entry_fee=entry_fee,
+                              currency=curname))
             return
 
         arena = Arena(msg.channel, entry_fee, on_arena_ended_func=_remove_running_arena_entry)
